@@ -237,12 +237,11 @@ class Chapter(object):
         child_folder = goal_dir / self._folder
         if not child_folder.exists():
             child_folder.mkdir(parents=True, exist_ok=True)
-        child_filename = self._figures_dir / f"{self._filename}.{self._fmt}"
+        filename: str = f"{self._filename}_{'_'.join(self._location)}.{self._fmt}"
+        child_filename = self._figures_dir / filename
         child_filename_tex = child_folder / f"{self._filename}.tex"
         # fig_desc["path"] = child_filename
-        fig_desc[
-            "path"
-        ] = f"{self._figures_dir.parts[-1]}/{self._filename}_{'_'.join(self._location)}.{self._fmt}"
+        fig_desc["path"] = f"{self._figures_dir.parts[-1]}/{filename}"
         t = type(fig)
         # check if t is of type matplotlib figure
         if t.__module__ == (mm := "matplotlib.figure"):
